# Wordlerer

Wordlerer can automatically solve wordle puzzle in the browser.

## Installation

```shell
pip install wordlerer
```

## Usage

```python
from wordlerer import BrowserApp

BrowserApp().run()
```
